==> tenant-domain-1.1.77-sources.jar: com/xforceplus/domain/tenant/RoleUserDto.java <==
package com.xforceplus.domain.tenant;


import com.xforceplus.domain.account.AccountDto;
import com.xforceplus.domain.org.OrgDto;
import com.xforceplus.domain.org.OrgExtensionDto;
import com.xforceplus.domain.user.UserDto;

/***
 * @author geewit
 */
@SuppressWarnings("all")
public class RoleUserDto<R extends RoleDto, U extends UserDto<O, R, A>, O extends OrgDto<O>, A extends AccountDto> {
    private Long id;
    private Long roleId;
    private Long userId;
    private Long userGroupId;
    private Long tenantId;

    private R role;

    private U user;


    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getRoleId() {
        return roleId;
    }

    public void setRoleId(Long roleId) {
        this.roleId = roleId;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public Long getUserGroupId() {
        return userGroupId;
    }

    public void setUserGroupId(Long userGroupId) {
        this.userGroupId = userGroupId;
    }

    public Long getTenantId() {
        return tenantId;
    }

    public void setTenantId(Long tenantId) {
        this.tenantId = tenantId;
    }


    public R getRole() {
        return role;
    }

    public void setRole(R role) {
        this.role = role;
    }

    public U getUser() {
        return user;
    }

    public void setUser(U user) {
        this.user = user;
    }
}

==> tenant-domain-1.1.105-sources.jar: com/xforceplus/domain/tenant/RoleUserDto.java <==
package com.xforceplus.domain.tenant;


import com.xforceplus.domain.account.AccountDto;
import com.xforceplus.domain.org.OrgDto;
import com.xforceplus.domain.org.OrgExtensionDto;
import com.xforceplus.domain.user.UserDto;

/***
 * @author geewit
 */
@SuppressWarnings("all")
public class RoleUserDto<R extends RoleDto, U extends UserDto<O, R, A>, O extends OrgDto<O>, A extends AccountDto> {
    private Long id;
    private Long roleId;
    private Long userId;
    private Long userGroupId;
    private Long tenantId;
    private Integer relType;

    private R role;

    private U user;


    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getRoleId() {
        return roleId;
    }

    public void setRoleId(Long roleId) {
        this.roleId = roleId;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public Long getUserGroupId() {
        return userGroupId;
    }

    public void setUserGroupId(Long userGroupId) {
        this.userGroupId = userGroupId;
    }

    public Long getTenantId() {
        return tenantId;
    }

    public void setTenantId(Long tenantId) {
        this.tenantId = tenantId;
    }


    public R getRole() {
        return role;
    }

    public void setRole(R role) {
        this.role = role;
    }

    public U getUser() {
        return user;
    }

    public void setUser(U user) {
        this.user = user;
    }

    public Integer getRelType() {
        return relType;
    }

    public void setRelType(Integer relType) {
        this.relType = relType;
    }
}
